@@ -3,9 +3,8 @@ test_that(
     # Create a curling sheet plot
     wcf_sheet <- geom_curling("wcf")
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(wcf_sheet)[1], "gg")
-    expect_equal(class(wcf_sheet)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(wcf_sheet))
   }
 )
 
@@ -14,9 +13,8 @@ test_that(
     # Create a curling sheet plot
     wcf_sheet <- geom_curling("wcf", sheet_units = "in", rotation = 270)
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(wcf_sheet)[1], "gg")
-    expect_equal(class(wcf_sheet)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(wcf_sheet))
   }
 )
 
@@ -31,8 +29,7 @@ test_that(
       )
     )
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(wcf_sheet)[1], "gg")
-    expect_equal(class(wcf_sheet)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(wcf_sheet))
   }
 )
