@@ -3,9 +3,8 @@ test_that(
     # Create a football field plot
     nfl_field <- geom_football("nfl")
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(nfl_field)[1], "gg")
-    expect_equal(class(nfl_field)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(nfl_field))
   }
 )
 
@@ -14,9 +13,8 @@ test_that(
     # Create a football field plot
     cfl_field <- geom_football("cfl", field_units = "m", rotation = 270)
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(cfl_field)[1], "gg")
-    expect_equal(class(cfl_field)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(cfl_field))
   }
 )
 
@@ -25,8 +23,7 @@ test_that(
     # Create a football field plot
     ncaa_field <- geom_football("ncaa")
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(ncaa_field)[1], "gg")
-    expect_equal(class(ncaa_field)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(ncaa_field))
   }
 )
