@@ -3,9 +3,8 @@ test_that(
     # Create a volleyball court plot
     ncaa_court <- geom_volleyball("ncaa")
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(ncaa_court)[1], "gg")
-    expect_equal(class(ncaa_court)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(ncaa_court))
   }
 )
 
@@ -14,8 +13,7 @@ test_that(
     # Create a volleyball court plot
     fivb_court <- geom_volleyball("fivb", court_units = "ft", rotation = 270)
 
-    # Check the class of the resulting plot. This should be "gg" and "ggplot"
-    expect_equal(class(fivb_court)[1], "gg")
-    expect_equal(class(fivb_court)[2], "ggplot")
+    # Check the class of the resulting plot. This should be a ggplot object
+    expect_true(ggplot2::is_ggplot(fivb_court))
   }
 )
